@@ -2,13 +2,14 @@ package App::LDAP::Command::Migrate;
 
 use Modern::Perl;
 
+use Namespace::Dispatch;
+
 use Moose;
 
-with qw( App::LDAP::Role::Command
-         App::LDAP::Role::Stem );
+with 'MooseX::Getopt';
 
 sub run {
-    my ($self, ) = @_;
+
 }
 
 __PACKAGE__->meta->make_immutable;
